# -*- coding: utf-8 -*-
from django.views.generic import (
    CreateView,
    DeleteView,
    DetailView,
    UpdateView,
    ListView
)

from .models import (
	OutboxRequestLog,
)


class OutboxRequestLogCreateView(CreateView):

    model = OutboxRequestLog


class OutboxRequestLogDeleteView(DeleteView):

    model = OutboxRequestLog


class OutboxRequestLogDetailView(DetailView):

    model = OutboxRequestLog


class OutboxRequestLogUpdateView(UpdateView):

    model = OutboxRequestLog


class OutboxRequestLogListView(ListView):

    model = OutboxRequestLog




# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.views.generic import TemplateView

from . import views

urlpatterns = [
    url(
        regex="^OutboxRequestLog/~create/$",
        view=views.OutboxRequestLogCreateView.as_view(),
        name='OutboxRequestLog_create',
    ),
    url(
        regex="^OutboxRequestLog/(?P<pk>\d+)/~delete/$",
        view=views.OutboxRequestLogDeleteView.as_view(),
        name='OutboxRequestLog_delete',
    ),
    url(
        regex="^OutboxRequestLog/(?P<pk>\d+)/$",
        view=views.OutboxRequestLogDetailView.as_view(),
        name='OutboxRequestLog_detail',
    ),
    url(
        regex="^OutboxRequestLog/(?P<pk>\d+)/~update/$",
        view=views.OutboxRequestLogUpdateView.as_view(),
        name='OutboxRequestLog_update',
    ),
    url(
        regex="^OutboxRequestLog/$",
        view=views.OutboxRequestLogListView.as_view(),
        name='OutboxRequestLog_list',
    ),
	]



# -*- coding: utf-8 -*-

from django.db import models

from model_utils.models import TimeStampedModel


class OutboxRequestLog(TimeStampedModel):
    request_uuid = models.UUIDField(db_index=True)
    request_path = models.TextField()
    request_body = models.TextField(null=True, blank=True)
    request_flagged_duplicate = models.BooleanField()
    response_status_code = models.IntegerField()



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-02 04:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_outbox_middleware', '0002_outboxrequestlog_request_flagged_duplicate'),
    ]

    operations = [
        migrations.AlterField(
            model_name='outboxrequestlog',
            name='request_uuid',
            field=models.UUIDField(db_index=True),
        ),
    ]



from django.conf import settings
from django.http import HttpResponse

try:
    from django.utils.deprecation import MiddlewareMixin
except ImportError:
    MiddlewareMixin = object

from .models import OutboxRequestLog


class OutboxMiddleware(MiddlewareMixin):
    def process_request(self, request):
        if 'HTTP_OUTBOX_REQUEST_UUID' in request.META:
            if OutboxRequestLog.objects.filter(
                request_uuid=request.META['HTTP_OUTBOX_REQUEST_UUID'],
                response_status_code__lt=400
            ).exists():
                resp = HttpResponse("OK", status=202)
                resp['Outbox-Flagged-Duplicate'] = True
                return resp

    def process_response(self, request, response):
        if 'HTTP_OUTBOX_REQUEST_UUID' in request.META:

            if getattr(settings, 'OUTBOX_LOG_BODY', False):
                request_body = request.body
            else:
                request_body = None

            OutboxRequestLog.objects.create(
                request_uuid=request.META['HTTP_OUTBOX_REQUEST_UUID'],
                response_status_code=response.status_code,
                request_body=request_body,
                request_path=request.get_full_path(),
                request_flagged_duplicate=response.get('Outbox-Flagged-Duplicate', False),
            )

        return response



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-02 01:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_outbox_middleware', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='outboxrequestlog',
            name='request_flagged_duplicate',
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-01 00:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='OutboxRequestLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('request_uuid', models.UUIDField()),
                ('request_path', models.TextField()),
                ('request_body', models.TextField(blank=True, null=True)),
                ('response_status_code', models.IntegerField()),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
